@@ -1,6 +1,6 @@
 use common::array::{sort, sort_strings, transform};
 use common::create::{make_array, make_array_entry, make_comma, make_entry_of_string, make_newline};
-use common::pep508::{format_requirement, get_canonic_requirement_name};
+use common::pep508::Requirement;
 use common::string::{load_text, update_content};
 use common::table::{collapse_sub_tables, for_entries, reorder_table_keys, Tables};
 use common::taplo::syntax::SyntaxKind::{
@@ -26,42 +26,47 @@ pub fn fix(
         return;
     }
     let table = &mut table_element.unwrap().first().unwrap().borrow_mut();
+    let re = Regex::new(r" \.(\W)").unwrap();
     expand_entry_points_inline_tables(table);
     for_entries(table, &mut |key, entry| match key.split('.').next().unwrap() {
         "name" => {
-            update_content(entry, get_canonic_requirement_name);
+            update_content(entry, |s| Requirement::new(s).unwrap().canonical_name());
         }
         "version" | "readme" | "license-files" | "scripts" | "entry-points" | "gui-scripts" => {
             update_content(entry, |s| String::from(s));
         }
         "description" => {
             update_content(entry, |s| {
-                s.trim()
-                    .lines()
-                    .map(|part| {
-                        part.trim()
-                            .split(char::is_whitespace)
-                            .filter(|part| !part.trim().is_empty())
-                            .collect::<Vec<&str>>()
-                            .join(" ")
-                            .replace(" .", ".")
-                    })
-                    .collect::<Vec<String>>()
-                    .join(" ")
+                re.replace_all(
+                    &s.trim()
+                        .lines()
+                        .map(|part| {
+                            part.split_whitespace()
+                                .filter(|part| !part.trim().is_empty())
+                                .collect::<Vec<&str>>()
+                                .join(" ")
+                        })
+                        .collect::<Vec<String>>()
+                        .join(" "),
+                    ".$1",
+                )
+                .to_string()
             });
         }
         "requires-python" => {
             update_content(entry, |s| s.split_whitespace().collect());
         }
         "dependencies" | "optional-dependencies" => {
-            transform(entry, &|s| format_requirement(s, keep_full_version));
+            transform(entry, &|s| {
+                Requirement::new(s).unwrap().normalize(keep_full_version).to_string()
+            });
             sort::<(String, String), _, _>(
                 entry,
                 |node| {
                     for child in node.children_with_tokens() {
                         if let STRING = child.kind() {
                             let val = load_text(child.as_token().unwrap().text(), STRING);
-                            let package_name = get_canonic_requirement_name(val.as_str()).to_lowercase();
+                            let package_name = Requirement::new(val.as_str()).unwrap().canonical_name();
                             return Some((package_name, val));
                         }
                     }
@@ -328,9 +333,7 @@ fn get_python_requires_with_classifier(
                 if child.kind() == STRING {
                     let found_str_value = load_text(child.as_token().unwrap().text(), STRING);
                     for part in found_str_value.split(',') {
-                        let capture = re.captures(part);
-                        if capture.is_some() {
-                            let caps = capture.unwrap();
+                        if let Some(caps) = re.captures(part) {
                             let minor = caps["minor"].parse::<u8>().unwrap();
                             match &caps["op"] {
                                 "==" => {
